@@ -10,6 +10,7 @@ import itertools
 import os
 import errno
 from collections import defaultdict
+from pandas import isna
 
 import numpy as np
 import scipy.interpolate
@@ -23,10 +24,11 @@ from matplotlib.lines import Line2D
 from matplotlib.patches import Rectangle, Patch
 from matplotlib.ticker import FuncFormatter
 
+import atomica
 import sciris as sc
 from .model import Compartment, Characteristic, Parameter, Link, TimedLink, SourceCompartment, JunctionCompartment, SinkCompartment
 from .results import Result
-from .system import logger
+from .system import logger, NotFoundError
 from .function_parser import parse_function
 from .system import FrameworkSettings as FS
 from .utils import format_duration, nested_loop
@@ -232,7 +234,13 @@ class PlotData:
 
                 # First pass, extract the original output quantities, summing links and annualizing as required
                 for output_label in outputs_required:
-                    vars = pop.get_variable(output_label)
+
+                    try:
+                        vars = pop.get_variable(output_label)
+                    except NotFoundError as e:
+                        in_pops = [x.name for x in result.model.pops if output_label in x]
+                        message = f'Variable "{output_label}" was requested in population "{pop.name}" but it is only defined in these populations: {in_pops}'
+                        raise NotFoundError(message) from e
 
                     if vars[0].vals is None:
                         raise Exception('Requested output "%s" was not recorded because only partial results were saved' % (vars[0].name))
@@ -431,7 +439,7 @@ class PlotData:
 
         for s in self.series:
             if accumulation_method == "sum":
-                if s.timescale is not None:
+                if not isna(s.timescale):
                     raise Exception('Quantity "%s" has timescale %g which means it should be accumulated by integration, not summation' % (s.output, s.timescale))
                 s.vals = np.cumsum(s.vals)
             elif accumulation_method == "integrate":
@@ -443,7 +451,7 @@ class PlotData:
 
                 # If integrating a quantity with a timescale, then lose the timescale factor
                 # Otherwise, the units pick up a factor of time
-                if s.timescale is not None:
+                if not isna(s.timescale):
                     s.timescale = None
                 else:
                     if s.units == "Number of people":
@@ -522,7 +530,7 @@ class PlotData:
                 if method == "integrate" and s.units in {FS.QUANTITY_TYPE_DURATION, FS.QUANTITY_TYPE_PROBABILITY, FS.QUANTITY_TYPE_RATE, FS.QUANTITY_TYPE_PROPORTION, FS.QUANTITY_TYPE_FRACTION}:
                     logger.warning('Units for series "%s" are "%s" so time aggregation should probably be "average", not "integrate"', s, s.units)
 
-            if s.timescale is not None:
+            if not isna(s.timescale):
                 scale = s.timescale
             else:
                 scale = 1.0
@@ -548,7 +556,7 @@ class PlotData:
                 s.vals = np.array(vals)
 
                 # If integrating the units might change
-                if s.timescale is not None:
+                if not isna(s.timescale):
                     # Any flow rates get integrated over the bin width, so change the timescale to None
                     # If the units were 'duration', this doesn't make sense, but integrating a duration doesn't
                     # make sense either. This would only happen if the user explicitly requests it anyway. For example,
@@ -1023,7 +1031,7 @@ class Series:
             logger.warning("%s contains NaNs", self)
 
     @property
-    def unit_string(self):
+    def unit_string(self) -> str:
         """
         Return the units for the quantity including timescale
 
@@ -1033,11 +1041,13 @@ class Series:
         The unit of the quantity is interpreted as a numerator if the Timescale is not None. For example,
         Compartments have units of 'number', while Links have units of 'number/timestep' which is stored as
         ``Series.units='number'`` and ``Series.timescale=0.25`` (if ``dt=0.25``). The `unit_string` attribute
+        returns a string that is suitable to use for plots e.g. 'number per week'.
+
+        :return: A string representation of the units for use in plotting
 
-        :return:
         """
 
-        if self.timescale is not None:
+        if not isna(self.timescale):
             if self.units == FS.QUANTITY_TYPE_DURATION:
                 return "%s" % (format_duration(self.timescale, True))
             else:
